;----------------------------------------------------------------------------
pro voronoi_2d_binning_example
;
; Usage example for the procedure VORONOI_2D_BINNING.
; Type the name VORONOI_2D_BINNING_EXAMPLE at the IDL
; prompt to run this example.
;
; It is assumed below that the file voronoi_2d_binning_example.txt
; resides in the current directory. Here columns 1-4 of the text file
; contain respectively the x, y coordinates of each SAURON lens
; and the corresponding Signal and Noise.
;
; POCEDURES NEEDED:
;   VORONOI_2D_BINNING: by M. Cappellari http://purl.org/cappellari/software
;   RDFLOAT: from IDL Astronomy User's Library http://idlastro.gsfc.nasa.gov/
;   FORPRINT: from IDL Astronomy User's Library http://idlastro.gsfc.nasa.gov/
;   ASTROLIB: from IDL Astronomy User's Library http://idlastro.gsfc.nasa.gov/
;
; V1.0.0: Michele Cappellari, Vicenza, 13 February 2003
; V1.0.1: Use astro library routines to read and write files.
;       MC, Leiden, 24 July 2003
; V1.0.2: Use /DOUBLE keyword in RDFLOAT to ensure unique solution to the binning.
;       This is generally irrelevant, but it is important when testing new
;       implementations of the algorithm. MC, Oxford, 21 March 2014

rdfloat, 'voronoi_2d_binning_example.txt', x, y, signal, noise, SKIPLINE=3, NUMLINE=3107, /DOUBLE
targetSN = 50.0

; Load a colortable and open a graphic window
;
loadct, 5
r = GET_SCREEN_SIZE()
window, xsize=r[0]*0.4, ysize=r[1]*0.8

; Perform the actual computation. The vectors
; (binNum, xNode, yNode, xBar, yBar, sn, nPixels, scale)
; are all generated in *output*
;
voronoi_2d_binning, x, y, signal, noise, targetSN, $
    binNum, xNode, yNode, xBar, yBar, sn, nPixels, scale, /PLOT

; Save to a text file the initial coordinates of each pixel together
; with the corresponding bin number computed by this procedure.
; binNum uniquely specifies the bins and for this reason it is the only
; number required for any subsequent calculation on the bins.
;
astrolib
forprint, x, y, binNum, TEXTOUT='voronoi_2d_binning_output.txt', $
    COMMENT='          X"              Y"           BIN_NUM'

END
;----------------------------------------------------------------------------
